@@ -29,11 +29,18 @@ class Dish(object):
         if args or kwargs:
             recipe = recipe(*args, **kwargs)
 
-        r.append(recipe)
+        if type(recipe) == Recipe:
+            r += recipe.recipe
+        else:
+            r.append(recipe)
         return Dish(recipe.cook(self.raw), recipe=r)
     
     def __repr__(self):
         return repr(self.raw)
+    def __str__(self):
+        if type(self.raw) == str:
+            return self.raw
+        return str(self.raw)
     
     def __add__(self, x):
         return Dish(self.raw + x, recipe=self.recipe)
